@@ -188,13 +188,14 @@ class DetDatumGenerator(DatumGenerator):
     image_filepath = os.path.join(data_path, image_dir, image_id + extension)
     annon_filepath = os.path.join(data_path, annon_dir, image_id + '.xml')
     if load_annotations:
-      xmin, xmax, ymin, ymax, label, pose, is_truncated, is_difficult = self._get_example_objects(
-          annon_filepath)
+      xmin, xmax, ymin, ymax, area, label, pose, is_truncated, is_difficult = \
+          self._get_example_objects(annon_filepath)
     else:
       xmin = []
       xmax = []
       ymin = []
       ymax = []
+      area = []
       label = []
       pose = []
       is_truncated = []
@@ -205,6 +206,7 @@ class DetDatumGenerator(DatumGenerator):
         "xmax": xmax,
         "ymin": ymin,
         "ymax": ymax,
+        "area": area,
         "pose": pose,
         "labels": label,
         "is_truncated": is_truncated,
@@ -224,6 +226,7 @@ class DetDatumGenerator(DatumGenerator):
       xmax: List[float] = []
       ymin: List[float] = []
       ymax: List[float] = []
+      area: List[float] = []
       label: List[int] = []
       pose: List[str] = []
       is_truncated: List[bool] = []
@@ -242,7 +245,8 @@ class DetDatumGenerator(DatumGenerator):
         xmin.append(float(bndbox.find("xmin").text) / width)
         ymax.append(float(bndbox.find("ymax").text) / height)
         ymin.append(float(bndbox.find("ymin").text) / height)
-      return xmin, xmax, ymin, ymax, label, pose, is_truncated, is_difficult
+        area.append((xmax[-1] - xmin[-1]) * (ymax[-1] - ymin[-1]))
+      return xmin, xmax, ymin, ymax, area, label, pose, is_truncated, is_difficult
 
 
 class SegDatumGenerator(DatumGenerator):
